@@ -7,5 +7,5 @@ class cos():
         return(self.x + self.y)
 
 class author():
-    def author():
+    def author(self):
         return("author olekps")
\ No newline at end of file
